@@ -290,6 +290,9 @@ REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
+# ResourceInUse.ResourceExistAlready
+RESOURCEINUSE_RESOURCEEXISTALREADY = 'ResourceInUse.ResourceExistAlready'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
